# `ingestr example-uris`

This command is supposed to serve as a guide for the user to understand the various URI formats that are supported by the `ingestr` tool. The command will provide a list of supported sources and destinations, along with the URI format for each of them.

For the detailed documentation, please refer to the [Sources & Destinations](../supported-sources/overview.md) section.
